/**
 * Iterate deep nested keys
 *
 * @param source: object
 * @param action: Function If property is not object, do Action
 */
function iterate(source, action) {
  Object.keys(source).forEach(function (key) {
    var property = Reflect.get(source, key);

    if (isObject(property)) {
      iterate(property, action);
      return;
    }

    if (isFunction(action)) {
      action(source, key);
    }
  });
}
/**
 * Check parameter is nullish
 *
 * @param value
 * @returns boolean If return true value is nullish
 */


function isNullish(value) {
  return value === undefined || value === null;
}
/**
 * Check parameter is Function
 *
 * @param value
 * @returns boolean If return true value is Function
 */


function isFunction(value) {
  return value !== null && typeof value === "function";
}
/**
 * Check parameter is Object
 *
 * @param value
 * @returns boolean If return true value is Object
 */


function isObject(value) {
  return value === Object(value);
}

// @ts-ignore
/**
 * Do remove nullish
 *
 * @param source Object has nullish or not
 * @param key source's key
 */

function doRemove(source, key) {
  if (!Reflect.has(source, key)) return;
  if (isNullish(Reflect.get(source, key))) Reflect.deleteProperty(source, key);
}
/**
 * Remove Nullish value.
 *
 * nullish : undefined, null
 *
 * @returns Object
 */


function removeNullish(source) {
  var result = Object.assign({}, source);
  iterate(result, doRemove);
  return result;
}

// @ts-ignore
var index = {
  removeNullish: removeNullish
};

export default index;
//# sourceMappingURL=nested-object-mutator.esm.js.map
